@@ -1,4 +1,4 @@
-from .__about__ import __author__, __email__, __license__, __status__, __version__
+from .__about__ import __version__
 from .geometry import (
     Circle,
     Difference,
@@ -17,11 +17,7 @@ from .geometry import (
 from .main import generate
 
 __all__ = [
-    "__author__",
-    "__email__",
-    "__license__",
     "__version__",
-    "__status__",
     "generate",
     "Circle",
     "Difference",
