@@ -1,9 +1,10 @@
 import numpy
 
 from ..helpers import multi_newton
+from .geometry import Geometry
 
 
-class Ellipse:
+class Ellipse(Geometry):
     def __init__(self, x0, a, b):
         self.x0 = x0
         self.a = a
@@ -12,18 +13,6 @@ class Ellipse:
         self.feature_points = numpy.array([])
         return
 
-    def plot(self, color="#1f77b4"):
-        import matplotlib.pyplot as plt
-
-        t = numpy.linspace(0.0, 2 * numpy.pi, 100)
-        plt.plot(
-            self.x0[0] + self.a * numpy.cos(t),
-            self.x0[1] + self.b * numpy.sin(t),
-            "-",
-            color=color,
-        )
-        return
-
     def dist(self, x):
         assert x.shape[0] == 2
         return (
