@@ -1,6 +1,7 @@
 import numpy
 
-import pypathlib
+from . import pypathlib
+from .geometry import Geometry
 
 
 class LineSegmentPath:
@@ -19,7 +20,7 @@ class LineSegmentPath:
         )
 
 
-class Polygon:
+class Polygon(Geometry):
     def __init__(self, points):
         points = numpy.array(points)
         self.bounding_box = [
@@ -36,11 +37,11 @@ class Polygon:
         ]
         self.diameter = self.polygon.diameter
 
-    def plot(self):
-        self.polygon.plot(color="C0")
-
     def dist(self, x):
-        return self.polygon.signed_distance(x.T)
+        assert x.shape[0] == 2
+        X = x.reshape(2, -1)
+        out = self.polygon.signed_distance(X.T)
+        return out.reshape(x.shape[1:])
 
     def boundary_step(self, x):
         return self.polygon.closest_points(x.T).T
