@@ -1,8 +1,16 @@
 import numpy
 
 
+def assert_equality(a, b, tol):
+    a = numpy.asarray(a)
+    b = numpy.asarray(b)
+    fmt_a = ", ".join(["{:.16e}"] * len(a))
+    fmt_b = ", ".join(["{:.16e}"] * len(b))
+    assert numpy.all(numpy.abs(a - b) < tol), f"[{fmt_a}]\n[{fmt_b}]".format(*a, *b)
+
+
 def assert_norm_equality(X, ref_norm, tol):
-    ref_norm = numpy.array(ref_norm)
+    ref_norm = numpy.asarray(ref_norm)
     vals = numpy.array(
         [
             numpy.linalg.norm(X, ord=1),
@@ -15,18 +23,12 @@ def assert_norm_equality(X, ref_norm, tol):
     ), "Expected: [{:.16e}, {:.16e}, {:.16e}]\nComputed: [{:.16e}, {:.16e}, {:.16e}]".format(
         *ref_norm, *vals
     )
-    return
 
 
 def save(filename, X, cells):
     import meshplex
 
-    mesh = meshplex.MeshTri(X, cells, flat_cell_correction=None)
+    mesh = meshplex.MeshTri(X, cells)
     mesh.save(
-        filename,
-        show_centroids=False,
-        show_coedges=False,
-        show_axes=False,
-        nondelaunay_edge_color="k",
+        filename, show_coedges=False, show_axes=False, nondelaunay_edge_color="k",
     )
-    return
