@@ -9,11 +9,9 @@ def test(show=False):
     )
     X, cells = dmsh.generate(geo, 1.0, show=show, tol=1.0e-3)
 
-    assert_norm_equality(
-        X.flatten(), [1.2599887992309357e02, 2.2109217065599051e01, 5.0], 1.0e-12
-    )
-    return
+    ref_norms = [1.4000000000000000e02, 2.3176757306973560e01, 5.0000000000000000e00]
+    assert_norm_equality(X.flatten(), ref_norms, 1.0e-10)
 
 
 if __name__ == "__main__":
-    test(show=False)
+    test(show=True)
